# -*- coding: utf-8 -*-
#
# Copyright © PyroLab Project Contributors
# Licensed under the terms of the GNU GPLv3+ License
# (see pyrolab/__init__.py for details)

"""
Oscilloscopes
=============

Submodule containing drivers for each supported scope type.
"""

from pyrolab.drivers import Instrument


class Scope(Instrument):
    pass
